@@ -49,6 +49,7 @@ update_ggside.ggplot <- function(object, ggside = NULL){
   object$ggside$ysidex <- ggside$ysidex %||% object$ggside$ysidex %||% NULL
   object$ggside$draw_x_on <- ggside$draw_x_on %||% object$ggside$draw_x_on %||% "default"
   object$ggside$draw_y_on <- ggside$draw_y_on %||% object$ggside$draw_y_on %||% "default"
+  object$ggside$strip <- ggside$strip %||% object$ggside$strip %||% "default"
   object[['facet']] <- as_ggsideFacet(object[['facet']], object[['ggside']])
   object[['coordinates']] <- as_ggsideCoord(object[['coordinates']])
   return(object)
@@ -70,9 +71,37 @@ ggplot_add.ggside_options <- function(object, plot, object_name){
 #' @export
 ggplot_add.ggside_scale <- function(object, plot, object_name){
   plot$ggside[[intersect(c("xsidey","ysidex"), object$aesthetics)]] <- object #save scale in appropriate place
+  old_scales <- plot$scales
+  if (!inherits(old_scales, "ggsideScalesList")) {
+    plot$scales <- ggproto("ggsideScalesList",
+                           old_scales,
+                           scales = lapply(old_scales$scales, function(s) s$clone()),
+                           get_scales = function(self, output) {
+                             s <- ggproto_parent(old_scales, self)$get_scales(output)
+                             if (inherits(s, "ScaleContinuousPosition")) {
+                               f <- s$oob
+                               s$oob <- muffle_opts_warn(f)
+                             }
+                             s
+                           })
+  }
   as_ggside(plot)
 }
 
+muffle_opts_warn <- function(f) {
+  function(...) {
+    withCallingHandlers(
+      warning = function(cnd) {
+        msg <- conditionMessage(cnd)
+        if (grepl(".(<|>). not meaningful for factors", msg)) {
+          rlang::cnd_muffle(cnd)
+        }
+      },
+      f(...)
+    )
+  }
+}
+
 # as_ggside <- function(plot, ggside = NULL){
 #   plot <- make_ggside(plot, ggside)
 #   if(inherits(plot$coordinates, "CoordFlip")||inherits(plot$coordinates, "CoordPolar")){
@@ -89,28 +118,7 @@ get_sides <- function(layers){
   return(sides_used)
 }
 
-# make_ggside <- function(object, ggside){
-#   if(!is.ggside(object)){
-#     class(object) <- c("ggside", class(object))
-#   }
-#   object$ggside$x.pos <- ggside$x.pos %||% object$ggside$x.pos %||% "top"
-#   if(!object$ggside$x.pos%in%c("top","bottom")) {
-#     abort("x.pos may only be \"top\" or \"bottom\".")
-#   }
-#   object$ggside$y.pos <- ggside$y.pos %||% object$ggside$y.pos %||% "right"
-#   if(!object$ggside$y.pos%in%c("right","left")) {
-#     abort("y.pos may only be \"right\" or \"left\".")
-#   }
-#   object$ggside$scales <- ggside$scales %||% object$ggside$scales %||% "fixed"
-#   if(!object$ggside$scales%in%c("fixed","free","free_x","free_y")){
-#     abort("scales may only be \"fixed\", \"free\", \"free_x\" or \"free_y\".")
-#   }
-#   object$ggside$sides_used <- get_sides(object[["layers"]])
-#   object$ggside$collapse <- ggside$collapse %||% object$ggside$collapse %||% NULL
-#   object$ggside$xsidey <- ggside$xsidey %||% object$ggside$xsidey %||% NULL
-#   object$ggside$ysidex <- ggside$ysidex %||% object$ggside$ysidex %||% NULL
-#   return(object)
-# }
+
 
 check_collapse <- function(collapse, sides){
   if(!is.null(collapse)){
